API reference
=============

Training dataset
================

.. automodule:: nacl.dataset
    :members:
    :special-members:
    :private-members:               
    :member-order: bysource

The SALT2Like Model
===================

model
-----

.. automodule:: nacl.models.salt
   :members:
   :special-members:
   :private-members:
   :member-order: bysource

constraints
-----------

.. automodule:: nacl.models.constraints
   :members:
   :special-members:
   :private-members:
   :member-order: bysource

regularization
--------------

.. automodule:: nacl.models.regularization
   :members:
   :special-members:
   :private-members:
   :member-order: bysource

error models
------------

.. automodule:: nacl.models.variancemodels
   :members:
   :special-members:
   :private-members:
   :member-order: bysource


Minimization Framework
======================

.. automodule:: nacl.minimize
    :members:
    :special-members:
    :private-members:               
    :member-order: bysource


instrument models
=================

.. automodule:: nacl.instruments
    :members:
    :special-members:
    :private-members:               
    :member-order: bysource

